@@ -8,6 +8,8 @@ from yowsup.common import YowConstants
 import datetime
 import os
 import logging
+import threading
+import base64
 from yowsup.layers.protocol_groups.protocolentities      import *
 from yowsup.layers.protocol_presence.protocolentities    import *
 from yowsup.layers.protocol_messages.protocolentities    import *
@@ -20,7 +22,8 @@ from yowsup.layers.protocol_media.protocolentities       import *
 from yowsup.layers.protocol_media.mediauploader import MediaUploader
 from yowsup.layers.protocol_profiles.protocolentities    import *
 from yowsup.common.tools import Jid
-from yowsup.common.optionalmodules import PILOptionalModule, AxolotlOptionalModule
+from yowsup.common.optionalmodules import PILOptionalModule
+from yowsup.layers.axolotl.protocolentities.iq_key_get import GetKeysIqProtocolEntity
 
 logger = logging.getLogger(__name__)
 class YowsupCliLayer(Cli, YowInterfaceLayer):
@@ -31,7 +34,7 @@ class YowsupCliLayer(Cli, YowInterfaceLayer):
     EVENT_START             = "org.openwhatsapp.yowsup.event.cli.start"
     EVENT_SENDANDEXIT       = "org.openwhatsapp.yowsup.event.cli.sendandexit"
 
-    MESSAGE_FORMAT          = "[{FROM}({TIME})]:[{MESSAGE_ID}]\t {MESSAGE}"
+    MESSAGE_FORMAT          = "[%s(%s)]:[%s]\t %s"
 
     FAIL_OPT_PILLOW         = "No PIL library installed, try install pillow"
     FAIL_OPT_AXOLOTL        = "axolotl is not installed, try install python-axolotl"
@@ -72,8 +75,8 @@ class YowsupCliLayer(Cli, YowInterfaceLayer):
                 return alias
         return jid
 
-    def setCredentials(self, username, password):
-        self.getLayerInterface(YowAuthenticationProtocolLayer).setCredentials(username, password)
+    def setCredentials(self, username, keypair):
+        self.getLayerInterface(YowAuthenticationProtocolLayer).setCredentials(username, keypair)
 
         return "%s@s.whatsapp.net" % username
 
@@ -333,13 +336,10 @@ class YowsupCliLayer(Cli, YowInterfaceLayer):
 
     @clicmd("Get shared keys")
     def keys_get(self, jids):
-        with AxolotlOptionalModule(failMessage = self.__class__.FAIL_OPT_AXOLOTL) as importFn:
-            importFn()
-            from yowsup.layers.axolotl.protocolentities.iq_key_get import GetKeysIqProtocolEntity
-            if self.assertConnected():
-                jids = [self.aliasToJid(jid) for jid in jids.split(',')]
-                entity = GetKeysIqProtocolEntity(jids)
-                self.toLower(entity)
+        if self.assertConnected():
+            jids = [self.aliasToJid(jid) for jid in jids.split(',')]
+            entity = GetKeysIqProtocolEntity(jids)
+            self.toLower(entity)
 
     @clicmd("Send init seq")
     def seq(self):
@@ -366,7 +366,7 @@ class YowsupCliLayer(Cli, YowInterfaceLayer):
     @clicmd("Send message to a friend")
     def message_send(self, number, content):
         if self.assertConnected():
-            outgoingMessage = TextMessageProtocolEntity(content.encode("utf-8") if sys.version_info >= (3,0) else content, to = self.aliasToJid(number))
+            outgoingMessage = TextMessageProtocolEntity(content, to=self.aliasToJid(number))
             self.toLower(outgoingMessage)
 
     @clicmd("Broadcast message. numbers should comma separated phone numbers")
@@ -404,7 +404,6 @@ class YowsupCliLayer(Cli, YowInterfaceLayer):
             errorFn = lambda errorEntity, originalEntity: self.onRequestUploadError(jid, path, errorEntity, originalEntity)
             self._sendIq(entity, successFn, errorFn)
 
-            self._sendIq(entity, successFn, errorFn)
     @clicmd("Send typing state")
     def state_typing(self, jid):
         if self.assertConnected():
@@ -439,14 +438,9 @@ class YowsupCliLayer(Cli, YowInterfaceLayer):
     def L(self):
         if self.connected:
             return self.output("Already connected, disconnect first")
-        self.getLayerInterface(YowNetworkLayer).connect()
+        threading.Thread(target=lambda: self.getLayerInterface(YowNetworkLayer).connect()).start()
         return True
 
-    @clicmd("Login to WhatsApp", 0)
-    def login(self, username, b64password):
-        self.setCredentials(username, b64password)
-        return self.L()
-
     ######## receive #########
 
     @ProtocolEntityCallback("chatstate")
@@ -487,8 +481,6 @@ class YowsupCliLayer(Cli, YowInterfaceLayer):
             self.output(notificationData, tag = "Notification")
         else:
             self.output("From :%s, Type: %s" % (self.jidToAlias(notification.getFrom()), notification.getType()), tag = "Notification")
-        if self.sendReceipts:
-            self.toLower(notification.ack())
 
     @ProtocolEntityCallback("message")
     def onMessage(self, message):
@@ -502,38 +494,32 @@ class YowsupCliLayer(Cli, YowInterfaceLayer):
             messageOut = "Unknown message type %s " % message.getType()
             print(messageOut.toProtocolTreeNode())
 
-
         formattedDate = datetime.datetime.fromtimestamp(message.getTimestamp()).strftime('%d-%m-%Y %H:%M')
         sender = message.getFrom() if not message.isGroupMessage() else "%s/%s" % (message.getParticipant(False), message.getFrom())
-        output = self.__class__.MESSAGE_FORMAT.format(
-            FROM = sender,
-            TIME = formattedDate,
-            MESSAGE = messageOut.encode('latin-1').decode() if sys.version_info >= (3, 0) else messageOut,
-            MESSAGE_ID = message.getId()
-            )
+
+        output = self.__class__.MESSAGE_FORMAT % (sender, formattedDate, message.getId(), messageOut)
 
         self.output(output, tag = None, prompt = not self.sendReceipts)
         if self.sendReceipts:
             self.toLower(message.ack(self.sendRead))
             self.output("Sent delivered receipt"+" and Read" if self.sendRead else "", tag = "Message %s" % message.getId())
 
-
     def getTextMessageBody(self, message):
         return message.getBody()
 
     def getMediaMessageBody(self, message):
-        if message.getMediaType() in ("image", "audio", "video"):
+        if message.media_type in ("image", "audio", "video", "document"):
             return self.getDownloadableMediaMessageBody(message)
         else:
-            return "[Media Type: %s]" % message.getMediaType()
-
+            return "[Media Type: %s]" % message.media_type
 
     def getDownloadableMediaMessageBody(self, message):
-         return "[Media Type:{media_type}, Size:{media_size}, URL:{media_url}]".format(
-            media_type = message.getMediaType(),
-            media_size = message.getMediaSize(),
-            media_url = message.getMediaUrl()
-            )
+        return "[media_type={media_type}, length={media_size}, url={media_url}, key={media_key}]".format(
+            media_type=message.media_type,
+            media_size=message.file_length,
+            media_url=message.url,
+            media_key=base64.b64encode(message.media_key)
+        )
 
     def doSendMedia(self, mediaType, filePath, url, to, ip = None, caption = None):
         if mediaType == RequestUploadIqProtocolEntity.MEDIA_TYPE_IMAGE:
@@ -559,7 +545,7 @@ class YowsupCliLayer(Cli, YowInterfaceLayer):
             mediaUploader = MediaUploader(jid, self.getOwnJid(), filePath,
                                       resultRequestUploadIqProtocolEntity.getUrl(),
                                       resultRequestUploadIqProtocolEntity.getResumeOffset(),
-                                      successFn, self.onUploadError, self.onUploadProgress, async=False)
+                                      successFn, self.onUploadError, self.onUploadProgress, asynchronous=False)
             mediaUploader.start()
 
     def onRequestUploadError(self, jid, path, errorRequestUploadIqProtocolEntity, requestUploadIqProtocolEntity):
