@@ -17,15 +17,15 @@ class AndroidYowsupEnv(YowsupEnv):
         "YHNtYoIvt5R3X6YZylbPftF/8ayWTALBgcqhkjOOAQDBQADLwAwLAIUAKYCp0d6z4QQdyN74JDfQ2WCyi8CFDUM4CaNB+ceVXd" \
         "KtOrNTQcc0e+t"
 
-    _MD5_CLASSES = "uts7K11+PDyZE5R0ou+2Sw=="
+    _MD5_CLASSES = "bdZVQh58MKZaaeiYnh7wkw=="
     _KEY = "eQV5aq/Cg63Gsq1sshN9T3gh+UUp0wIw0xgHYT1bnCjEqOJQKCRrWxdAe2yvsDeCJL+Y4G3PRD2HUF7oUgiGo8vGlNJOaux26k+A2F3hj8A="
 
-    _VERSION = "2.17.337"
+    _VERSION = "2.19.51"
     _OS_NAME = "Android"
-    _OS_VERSION = "4.3"
-    _DEVICE_NAME = "endeavoru"
-    _MANUFACTURER = "HTC"
-    _BUILD_VERSION = "IMM76D"
+    _OS_VERSION = "8.0.0"
+    _DEVICE_NAME = "star2lte"
+    _MANUFACTURER = "samsung"
+    _BUILD_VERSION = "star2ltexx-user 8.0.0 R16NW G965FXXU1ARCC release-keys"
     _AXOLOTL = True
 
     def getVersion(self):
