@@ -4,5 +4,4 @@ from .response import ResponseProtocolEntity
 from .stream_features import StreamFeaturesProtocolEntity
 from .success import SuccessProtocolEntity
 from .failure import FailureProtocolEntity
-from .stream_error_conflict import StreamErrorConflictProtocolEntity
-from .stream_error_ack import StreamErrorAckProtocolEntity
+from .stream_error import StreamErrorProtocolEntity
