@@ -3,7 +3,8 @@ from yowsup.structs import ProtocolTreeNode
 from yowsup.structs.protocolentity import ProtocolEntityTest
 import unittest
 
+
 class FailureProtocolEntityTest(ProtocolEntityTest, unittest.TestCase):
     def setUp(self):
         self.ProtocolEntity = FailureProtocolEntity
-        self.node = ProtocolTreeNode("failure", {}, [ProtocolTreeNode("not-authorized", {})])
\ No newline at end of file
+        self.node = ProtocolTreeNode("failure", {"reason": "not-authorized"})
