@@ -3,15 +3,14 @@ from yowsup.structs import ProtocolTreeNode
 from yowsup.structs.protocolentity import ProtocolEntityTest
 import unittest
 
+
 class SuccessProtocolEntityTest(ProtocolEntityTest, unittest.TestCase):
     def setUp(self):
         self.ProtocolEntity = SuccessProtocolEntity
         attribs = {
-            "status": "active",
-            "kind": "free",
             "creation": "1234",
-            "expiration": "1446578937",
+            "location": "atn",
             "props": "2",
             "t": "1415470561"
         }
-        self.node = ProtocolTreeNode("success", attribs, None, "dummydata")
\ No newline at end of file
+        self.node = ProtocolTreeNode("success", attribs)
