@@ -3,6 +3,7 @@ from .iq_keys_set import SetKeysIqProtocolEntity
 from .iq_keys_get_result import ResultGetKeysIqProtocolEntity
 from .message_encrypted import EncryptedMessageProtocolEntity
 from .enc import EncProtocolEntity
-from .notification_encrypt import EncryptNotification
 from .receipt_outgoing_retry import RetryOutgoingReceiptProtocolEntity
 from .receipt_incoming_retry import RetryIncomingReceiptProtocolEntity
+from .notification_encrypt_identitychange import IdentityChangeEncryptNotification
+from .notification_encrypt_requestkeys import RequestKeysEncryptNotification
