@@ -10,6 +10,7 @@ import inspect
 import logging
 logger = logging.getLogger(__name__)
 
+
 class ProtocolEntityCallback(object):
     def __init__(self, entityType):
         self.entityType = entityType
@@ -36,8 +37,7 @@ class YowInterfaceLayer(YowLayer):
                 fn = m[1]
                 self.entity_callbacks[fn.entity_callback] = getattr(self, fname)
 
-
-    def _sendIq(self, iqEntity, onSuccess = None, onError = None):
+    def _sendIq(self, iqEntity, onSuccess=None, onError=None):
         assert iqEntity.getTag() == "iq", "Expected *IqProtocolEntity in _sendIq, got %s" % iqEntity.getTag()
         self.iqRegistry[iqEntity.getId()] = (iqEntity, onSuccess, onError)
         self.toLower(iqEntity)
@@ -52,7 +52,7 @@ class YowInterfaceLayer(YowLayer):
                 originalIq, successClbk, errorClbk = self.iqRegistry[iq_id]
                 del self.iqRegistry[iq_id]
 
-                if entity.getType() ==  IqProtocolEntity.TYPE_RESULT and successClbk:
+                if entity.getType() == IqProtocolEntity.TYPE_RESULT and successClbk:
                     successClbk(entity, originalIq)
                 elif entity.getType() == IqProtocolEntity.TYPE_ERROR and errorClbk:
                     errorClbk(entity, originalIq)
@@ -60,7 +60,7 @@ class YowInterfaceLayer(YowLayer):
 
         return False
 
-    def getOwnJid(self, full = True):
+    def getOwnJid(self, full=True):
         return self.getLayerInterface(YowAuthenticationProtocolLayer).getUsername(full)
 
     def connect(self):
@@ -91,7 +91,8 @@ class YowInterfaceLayer(YowLayer):
                 logger.info("Initiating reconnect")
                 self.reconnect = True
         else:
-            logger.warn("Not reconnecting because property %s is not set" % self.__class__.PROP_RECONNECT_ON_STREAM_ERR)
+            logger.warn("Not reconnecting because property %s is not set" %
+                        self.__class__.PROP_RECONNECT_ON_STREAM_ERR)
         self.toUpper(streamErrorEntity)
         self.disconnect()
 
@@ -105,30 +106,38 @@ class YowInterfaceLayer(YowLayer):
             self.reconnect = False
             self.connect()
 
-    def _sendMediaMessage(self, builder, success, error = None, progress = None):
+    def _sendMediaMessage(self, builder, success, error=None, progress=None):
         # axolotlIface = self.getLayerInterface(YowAxolotlLayer)
         # if axolotlIface:
         #     axolotlIface.encryptMedia(builder)
 
-        iq = RequestUploadIqProtocolEntity(builder.mediaType, filePath = builder.getFilepath(), encrypted = builder.isEncrypted())
-        successFn = lambda resultEntity, requestUploadEntity: self.__onRequestUploadSuccess(resultEntity, requestUploadEntity, builder, success, error, progress)
-        errorFn = lambda errorEntity, requestUploadEntity: self.__onRequestUploadError(errorEntity, requestUploadEntity, error)
+        iq = RequestUploadIqProtocolEntity(
+            builder.mediaType, filePath=builder.getFilepath(), encrypted=builder.isEncrypted())
+
+        def successFn(resultEntity, requestUploadEntity): return self.__onRequestUploadSuccess(
+            resultEntity, requestUploadEntity, builder, success, error, progress)
+
+        def errorFn(errorEntity, requestUploadEntity): return self.__onRequestUploadError(
+            errorEntity, requestUploadEntity, error)
         self._sendIq(iq, successFn, errorFn)
 
-    def __onRequestUploadSuccess(self, resultRequestUploadIqProtocolEntity, requestUploadEntity, builder, success, error = None, progress = None):
+    def __onRequestUploadSuccess(self, resultRequestUploadIqProtocolEntity, requestUploadEntity, builder, success, error=None, progress=None):
         if(resultRequestUploadIqProtocolEntity.isDuplicate()):
             return success(builder.build(resultRequestUploadIqProtocolEntity.getUrl(), resultRequestUploadIqProtocolEntity.getIp()))
         else:
-            successFn = lambda path, jid, url: self.__onMediaUploadSuccess(builder, url, resultRequestUploadIqProtocolEntity.getIp(), success)
-            errorFn = lambda path, jid, errorText: self.__onMediaUploadError(builder, errorText, error)
+            def successFn(path, jid, url): return self.__onMediaUploadSuccess(
+                builder, url, resultRequestUploadIqProtocolEntity.getIp(), success)
+
+            def errorFn(path, jid, errorText): return self.__onMediaUploadError(
+                builder, errorText, error)
 
             mediaUploader = MediaUploader(builder.jid, self.getOwnJid(), builder.getFilepath(),
-                                      resultRequestUploadIqProtocolEntity.getUrl(),
-                                      resultRequestUploadIqProtocolEntity.getResumeOffset(),
-                                      successFn, errorFn, progress, async=True)
+                                          resultRequestUploadIqProtocolEntity.getUrl(),
+                                          resultRequestUploadIqProtocolEntity.getResumeOffset(),
+                                          successFn, errorFn, progress, asynchronous=True)
             mediaUploader.start()
 
-    def __onRequestUploadError(self, errorEntity, requestUploadEntity, builder, error = None):
+    def __onRequestUploadError(self, errorEntity, requestUploadEntity, builder, error=None):
         if error:
             return error(errorEntity.code, errorEntity.text, errorEntity.backoff)
 
@@ -136,7 +145,7 @@ class YowInterfaceLayer(YowLayer):
         messageNode = builder.build(url, ip)
         return successClbk(messageNode)
 
-    def __onMediaUploadError(self, builder, errorText, errorClbk = None):
+    def __onMediaUploadError(self, builder, errorText, errorClbk=None):
         if errorClbk:
             return errorClbk(0, errorText, 0)
 
