@@ -1,16 +1,20 @@
-from yowsup.layers import YowLayer, YowLayerEvent, YowProtocolLayer
+from yowsup.layers import YowProtocolLayer
 from .protocolentities import ImageDownloadableMediaMessageProtocolEntity
 from .protocolentities import AudioDownloadableMediaMessageProtocolEntity
 from .protocolentities import VideoDownloadableMediaMessageProtocolEntity
+from .protocolentities import DocumentDownloadableMediaMessageProtocolEntity
 from .protocolentities import LocationMediaMessageProtocolEntity
-from .protocolentities import VCardMediaMessageProtocolEntity
-from .protocolentities import RequestUploadIqProtocolEntity, ResultRequestUploadIqProtocolEntity
+from .protocolentities import ContactMediaMessageProtocolEntity
+from .protocolentities import ResultRequestUploadIqProtocolEntity
+from .protocolentities import MediaMessageProtocolEntity
+from .protocolentities import ExtendedTextMediaMessageProtocolEntity
 from yowsup.layers.protocol_iq.protocolentities import IqProtocolEntity, ErrorIqProtocolEntity
+import logging
+
+logger = logging.getLogger(__name__)
+
 
 class YowMediaProtocolLayer(YowProtocolLayer):
-
-    # EVENT_REQUEST_UPLOAD = "org.openwhatsapp.org.yowsup.event.protocol_media.request_upload"
-
     def __init__(self):
         handleMap = {
             "message": (self.recvMessageStanza, self.sendMessageEntity),
@@ -21,37 +25,37 @@ class YowMediaProtocolLayer(YowProtocolLayer):
     def __str__(self):
         return "Media Layer"
 
-    # def onEvent(self, yowLayerEvent):
-    #     if yowLayerEvent.getArg(self.__class__.EVENT_REQUEST_UPLOAD):
-    #         fpath = yowLayerEvent.getArg("file")
-    #         _type = yowLayerEvent.getArg("type")
-    #         assert fpath and _type, "Must specify 'file' and 'type' in EVENT_REQUEST_UPLOAD args"
-    #         entity = RequestUploadIqProtocolEntity(_type, filePath=fpath)
-    #         self._sendIq(entity, self.onRequestUploadSuccess, self.onRequestUploadError)
-
-
     def sendMessageEntity(self, entity):
         if entity.getType() == "media":
             self.entityToLower(entity)
 
     def recvMessageStanza(self, node):
         if node.getAttributeValue("type") == "media":
-            mediaNode = node.getChild("media")
-            if mediaNode.getAttributeValue("type") == "image":
+            mediaNode = node.getChild("proto")
+            if mediaNode.getAttributeValue("mediatype") == "image":
                 entity = ImageDownloadableMediaMessageProtocolEntity.fromProtocolTreeNode(node)
                 self.toUpper(entity)
-            elif mediaNode.getAttributeValue("type") == "audio":
+            elif mediaNode.getAttributeValue("mediatype") in ("audio", "ptt"):
                 entity = AudioDownloadableMediaMessageProtocolEntity.fromProtocolTreeNode(node)
                 self.toUpper(entity)
-            elif mediaNode.getAttributeValue("type") == "video":
+            elif mediaNode.getAttributeValue("mediatype") in ("video", "gif"):
                 entity = VideoDownloadableMediaMessageProtocolEntity.fromProtocolTreeNode(node)
                 self.toUpper(entity)
-            elif mediaNode.getAttributeValue("type") == "location":
+            elif mediaNode.getAttributeValue("mediatype") == "location":
                 entity = LocationMediaMessageProtocolEntity.fromProtocolTreeNode(node)
                 self.toUpper(entity)
-            elif mediaNode.getAttributeValue("type") == "vcard":
-                entity = VCardMediaMessageProtocolEntity.fromProtocolTreeNode(node)
+            elif mediaNode.getAttributeValue("mediatype") == "contact":
+                entity = ContactMediaMessageProtocolEntity.fromProtocolTreeNode(node)
                 self.toUpper(entity)
+            elif mediaNode.getAttributeValue("mediatype") == "document":
+                entity = DocumentDownloadableMediaMessageProtocolEntity.fromProtocolTreeNode(node)
+                self.toUpper(entity)
+            elif mediaNode.getAttributeValue("mediatype") == "url":
+                entity = ExtendedTextMediaMessageProtocolEntity.fromProtocolTreeNode(node)
+                self.toUpper(entity)
+            else:
+                logger.warn("Unsupported mediatype: %s, will send receipts" % mediaNode.getAttributeValue("mediatype"))
+                self.toLower(MediaMessageProtocolEntity.fromProtocolTreeNode(node).ack(True).toProtocolTreeNode())
 
     def sendIq(self, entity):
         """
