@@ -3,7 +3,9 @@ from .message_media_downloadable import DownloadableMediaMessageProtocolEntity
 from .message_media_downloadable_image import ImageDownloadableMediaMessageProtocolEntity
 from .message_media_downloadable_audio import AudioDownloadableMediaMessageProtocolEntity
 from .message_media_downloadable_video import VideoDownloadableMediaMessageProtocolEntity
+from .message_media_downloadable_document import DocumentDownloadableMediaMessageProtocolEntity
 from .message_media_location import LocationMediaMessageProtocolEntity
-from .message_media_vcard import VCardMediaMessageProtocolEntity
+from .message_media_contact import ContactMediaMessageProtocolEntity
+from .message_media_extendedtext import ExtendedTextMediaMessageProtocolEntity
 from .iq_requestupload import RequestUploadIqProtocolEntity
 from .iq_requestupload_result import ResultRequestUploadIqProtocolEntity
