@@ -1,4 +1,4 @@
-from yowsup.layers import YowLayer, YowLayerEvent, YowProtocolLayer
+from yowsup.layers import YowProtocolLayer
 from .protocolentities import TextMessageProtocolEntity
 class YowMessagesProtocolLayer(YowProtocolLayer):
     def __init__(self):
@@ -16,7 +16,9 @@ class YowMessagesProtocolLayer(YowProtocolLayer):
 
     ###recieved node handlers handlers
     def recvMessageStanza(self, node):
-        if node.getAttributeValue("type") == "text":
-            entity = TextMessageProtocolEntity.fromProtocolTreeNode(node)
-            self.toUpper(entity) 
+        protoNode = node.getChild("proto")
+
+        if protoNode:
+           if protoNode and protoNode["mediatype"] is None:
+               self.toUpper(TextMessageProtocolEntity.fromProtocolTreeNode(node))
 
