@@ -1,6 +1,12 @@
 from yowsup.layers import YowLayer, YowLayerEvent, YowProtocolLayer
 from .protocolentities import *
 from yowsup.layers.protocol_acks.protocolentities import OutgoingAckProtocolEntity
+import logging
+
+
+logger = logging.getLogger(__name__)
+
+
 class YowNotificationsProtocolLayer(YowProtocolLayer):
 
     def __init__(self):
@@ -26,21 +32,14 @@ class YowNotificationsProtocolLayer(YowProtocolLayer):
                 self.raiseErrorForNode(node)
         elif node["type"] == "status":
             self.toUpper(StatusNotificationProtocolEntity.fromProtocolTreeNode(node))
-        elif node["type"] == "features":
-            # Not implemented
-            pass
-        elif node["type"] in [ "contacts", "subject", "w:gp2" ]:
+        elif node["type"] in ["contacts", "subject", "w:gp2"]:
             # Implemented in respectively the protocol_contacts and protocol_groups layer
             pass
-        elif node["type"] == "contacts":
-            pass
-        elif node["type"] == "web":
-            # Not implemented
-            pass
         else:
-            self.raiseErrorForNode(node)
+            logger.warn("Unsupported notification type: %s " % node["type"])
+            logger.debug("Unsupported notification node: %s" % node)
 
-        ack = OutgoingAckProtocolEntity(node["id"], "notification", node["type"], node["from"])
+        ack = OutgoingAckProtocolEntity(node["id"], "notification", node["type"], node["from"], participant=node["participant"])
         self.toLower(ack.toProtocolTreeNode())
 
 
