@@ -1,11 +1,10 @@
 from .yowstack import YowStack, YowStackBuilder
 
-from yowsup.layers.auth                        import YowCryptLayer, YowAuthenticationProtocolLayer, AuthError
+from yowsup.layers.auth                        import YowAuthenticationProtocolLayer
 from yowsup.layers.coder                       import YowCoderLayer
 from yowsup.layers.logger                      import YowLoggerLayer
 from yowsup.layers.network                     import YowNetworkLayer
 from yowsup.layers.protocol_messages           import YowMessagesProtocolLayer
-from yowsup.layers.stanzaregulator             import YowStanzaRegulator
 from yowsup.layers.protocol_media              import YowMediaProtocolLayer
 from yowsup.layers.protocol_acks               import YowAckProtocolLayer
 from yowsup.layers.protocol_receipts           import YowReceiptProtocolLayer
@@ -19,14 +18,16 @@ from yowsup.layers.protocol_chatstate          import YowChatstateProtocolLayer
 from yowsup.layers.protocol_privacy            import YowPrivacyProtocolLayer
 from yowsup.layers.protocol_profiles           import YowProfilesProtocolLayer
 from yowsup.layers.protocol_calls              import YowCallsProtocolLayer
+from yowsup.layers.noise.layer                 import YowNoiseLayer
+from yowsup.layers.noise.layer_noise_segments  import YowNoiseSegmentsLayer
 
 
 
 YOWSUP_CORE_LAYERS = (
     YowLoggerLayer,
     YowCoderLayer,
-    YowCryptLayer,
-    YowStanzaRegulator,
+    YowNoiseLayer,
+    YowNoiseSegmentsLayer,
     YowNetworkLayer
 )
 
