@@ -11,7 +11,7 @@ class ProtocolEntity(object):
 
     def isType(self,  typ):
         return self.tag == typ
-    
+
     def _createProtocolTreeNode(self, attributes, children = None, data = None):
         return ProtocolTreeNode(self.getTag(), attributes, children, data)
 
@@ -22,8 +22,8 @@ class ProtocolEntity(object):
     def _generateId(self, short = False):
         ProtocolEntity.__ID_GEN += 1
         return str(ProtocolEntity.__ID_GEN) if short else str(int(time.time())) + "-" + str(ProtocolEntity.__ID_GEN)
-        
-    
+
+
     def toProtocolTreeNode(self):
         pass
 
@@ -32,11 +32,17 @@ class ProtocolEntity(object):
         pass
 
 
-class ProtocolEntityTest(unittest.TestCase):
+class ProtocolEntityTest(object):
     def setUp(self):
-        self.skipTest("override in child classes")
+        self.ProtocolEntity = None
+        self.node = None
+
+    # def assertEqual(self, entity, node):
+    #     raise AssertionError("Should never execute that")
 
     def test_generation(self):
+        if self.ProtocolEntity is None:
+            raise ValueError("Test case not setup!")
         entity = self.ProtocolEntity.fromProtocolTreeNode(self.node)
         try:
             self.assertEqual(entity.toProtocolTreeNode(), self.node)
